@@ -1,3 +1,4 @@
+use crate::io::storage::Storage;
 use crate::messagebox::MessageBox;
 use crate::natives_and_messaging::*;
 use crate::window::{Application, Frame, WindowAttributes};
@@ -15,16 +16,17 @@ impl DemoWindow {
 }
 
 impl Application for DemoWindow {
-    fn title(&self) -> String {
+    fn app_name(&self) -> String {
         "Demo Application".to_string()
     }
 
     fn attributes(&self) -> WindowAttributes {
-        WindowAttributes::new(WINDOWSTYLE_NORMAL, 1280, 750, 500, 500)
+        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 500, 500)
     }
 
-    fn startup(&self) {
+    fn startup(&self,storage: Storage) {
         println!("Startup!");
+        println!("Config dir is {}",storage.get_config_dir().as_os_str().to_str().unwrap());
     }
 
     fn ui(&self,frame: Frame) {
