@@ -1,5 +1,7 @@
 //! Provides traits and tools for displaying windows.
 
+use crate::io::storage::Storage;
+
 pub mod demowindow;
 
 #[cfg(windows)]
@@ -65,6 +67,7 @@ impl Frame {
 #[cfg(windows)]
 pub struct WindowAttributes {
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
+    pub title: String,
     pub width: i32,
     pub height: i32,
     pub x: i32,
@@ -73,9 +76,10 @@ pub struct WindowAttributes {
 
 #[cfg(windows)]
 impl WindowAttributes {
-    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
         Self {
             style,
+            title,
             width,
             height,
             x,
@@ -86,12 +90,12 @@ impl WindowAttributes {
 
 #[cfg(windows)]
 pub trait Application {
-    /// Returns the name of the window.
-    fn title(&self) -> String;
+    /// Returns the name of the application.
+    fn app_name(&self) -> String;
     /// Returns WindowAttributes.
     fn attributes(&self) -> WindowAttributes;
     /// Processing at application startup (optional)
-    fn startup(&self) {
+    fn startup(&self,storage: Storage) {
 
     }
     /// Writing UI processes and events
@@ -158,6 +162,7 @@ impl Frame {
 #[cfg(unix)]
 pub struct WindowAttributes {
     pub style: gtk::WindowType,
+    pub title: String,
     pub width: i32,
     pub height: i32,
     pub x: i32,
@@ -166,9 +171,10 @@ pub struct WindowAttributes {
 
 #[cfg(unix)]
 impl WindowAttributes {
-    pub fn new(style: gtk::WindowType,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: gtk::WindowType,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
         Self {
             style,
+            title,
             width,
             height,
             x,
@@ -180,11 +186,11 @@ impl WindowAttributes {
 #[cfg(unix)]
 pub trait Application {
     /// Returns the name of the window.
-    fn title(&self) -> String;
+    fn app_name(&self) -> String;
     /// Returns WindowAttributes.
     fn attributes(&self) -> WindowAttributes;
     /// Processing at application startup (optional)
-    fn startup(&self) {
+    fn startup(&self,storage: Storage) {
 
     }
     /// Writing UI processes and events
